@@ -1,4 +1,4 @@
-use weighted_rand::builder::WalkerTableBuilder;
+use weighted_rand::builder::*;
 
 fn main() {
     let fruit = ["Apple", "Banana", "Orange", "Peach"];
@@ -10,7 +10,7 @@ fn main() {
     // for each index are 0.2, 0.1, 0.7 and 0.
     let index_weights = vec![2, 1, 7, 0];
 
-    let mut builder = WalkerTableBuilder::new(index_weights);
+    let builder = WalkerTableBuilder::new(&index_weights);
     let wa_table = builder.build();
 
     for _ in 0..10 {
