@@ -10,7 +10,7 @@
 //! ## Example
 //!
 //! ```rust
-//! use weighted_rand::builder::WalkerTableBuilder;
+//! use weighted_rand::builder::*;
 //!
 //! fn main() {
 //!     let fruit = ["Apple", "Banana", "Orange", "Peach"];
@@ -22,7 +22,7 @@
 //!     // for each index are 0.2, 0.1, 0.7 and 0.
 //!     let index_weights = vec![2, 1, 7, 0];
 //!
-//!     let mut builder = WalkerTableBuilder::new(index_weights);
+//!     let builder = WalkerTableBuilder::new(&index_weights);
 //!     let wa_table = builder.build();
 //!
 //!     for _ in 0..10 {
@@ -32,6 +32,28 @@
 //! }
 //! ```
 //!
+//! Also, `index_weiaghts` supports [`Vec<f32>`], like:
+//!
+//! ```rust
+//! use weighted_rand::builder::*;
+//!
+//! fn main() {
+//!     // Coins with a 5% higher probability of heads than tails
+//!     let cheating_coin = ["Heads!", "Tails!"];
+//!     let index_weights = vec![0.55, 0.45];
+//!
+//!     let builder = WalkerTableBuilder::new(&index_weights);
+//!     let wa_table = builder.build();
+//!
+//!     for _ in 0..10 {
+//!         let i = wa_table.next();
+//!         println!("{}", cheating_coin[i]);
+//!     }
+//! }
+//! ```
+//!
 
 pub mod builder;
 pub mod table;
+
+mod util;
